CMP_Range_Position

Function CMP_Range_Position 

fn CMP_Range_Position(A: &RPCRangeDTO, B: &RPCRangeDTO) -> Ordering
Compares two RPC ranges to determine their order in the document. Returns negative if a comes before b, zero if equal, positive if a comes after b.